@@ -105,7 +105,7 @@ def set_svg_background_images(lecture_tex, verbose=False,
     s = s[:ii] + "\n \\togglefalse{overlabel_includesvgs}\n\\toggletrue{overlabel_includelabels}\n" + s[ii:]
 
     with open(lecture_tex_nosvg, "w") as f:
-        f.write(s)
+        f.write(''.join([i if ord(i) < 128 else '-' for i in s]))
 
     lecture_tex_nosvg_pdf = lecture_tex_nosvg[:-4] + ".pdf"
 
